<img src = "res/GRID_logo.png" width = 100>

# GRID

![](https://img.shields.io/github/license/poissonfish/photo_grid)
![](https://img.shields.io/pypi/v/photo_grid)
![](https://img.shields.io/pypi/dm/photo_grid)
![](https://img.shields.io/pypi/implementation/photo_grid)
![](https://img.shields.io/github/languages/code-size/poissonfish/photo_grid)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/626008b19df543ecb33a78e8f82f5e91)](https://www.codacy.com/manual/Poissonfish/photo_grid?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Poissonfish/photo_grid&amp;utm_campaign=Badge_Grade)

## Github page

https://poissonfish.github.io/GRID/ls

## Update Log

### Oct 29, 2019 (0.2.0)
    * Add progress bars
    * Enhance the support for low resolution monitors
    * Improve UI
  
### Oct 22, 2019 (0.1.3)
    * Optimize default setting of refining parameters
    * Fix wrong angle detection
    * Minor bug fixes

### Oct 19, 2019 (0.1.2)
    * Support rhombus field layout
    * Bug fixes

### Sep 17, 2019 (0.0.16)
    * Improve memory efficiency on Windows OS

### Sep 12, 2019 (0.0.15)
    * Fix problems wiht fixed segmentation
    * Organize file structure
    * Add dark mode
